#pragma GCC optimize("Ofast")

#include <iostream>
#include <algorithm>
#include <vector>
#include <set>
#include <map>
#include <cassert>

using namespace std;

typedef long long ll;

const int N = 3e5 + 7;
const int INF = 1e9 + 239;

struct Edge {
	int u, v, c;

	Edge() {}

	Edge(int u_, int v_, int c_) {
		u = u_;
		v = v_;
		c = c_;
	}

	bool operator<(const Edge &other) const {
		return c < other.c;
	}
};

int n;
ll ans[N];
vector<Edge> E;

vector<int> g[N];
vector<pair<int, int>> ng[N];

int timer = 0;
int used[N];
int tin[N];
int fup[N];
int comp[N];
int me[N];
int isb[N];
ll ac[N];

void dfs_bridge(int cur, int p) {
	used[cur] = 1;
	tin[cur] = timer++;
	fup[cur] = tin[cur];
	for (auto ind : g[cur]) {
		int t = E[ind].u ^ E[ind].v ^ cur;
		if (ind == p) continue;
		if (used[t]) {
			fup[cur] = min(fup[cur], tin[t]);
		} else {
			dfs_bridge(t, ind);
			fup[cur] = min(fup[cur], fup[t]);
		}
		if (tin[cur] < fup[t]) {
			isb[ind] = 1;
		}
	}
}

void dfs_ignore(int cur, int c) {
	used[cur] = 1;
	comp[cur] = c;
	for (auto ind : g[cur]) {
		int t = E[ind].u ^ E[ind].v ^ cur;
		if (!used[t] && !isb[ind]) {
			dfs_ignore(t, c);
		}
	}
}

void dfs_ans(int cur, int p, int mn) {
	mn = min(mn, me[cur]);
	ac[cur] = mn;
	for (auto [t, w] : ng[cur]) {
		if (t != p) {
			dfs_ans(t, cur, min(mn, w));
		}
	}
}

void solve(int last) {
	for (int i = 0; i < n; i++) {
		used[i] = 0;
		g[i].clear();
		ng[i].clear();
		me[i] = INF;
		ac[i] = 2LL * INF;
	}
	for (int i = 0; i < last; i++) {
		g[E[i].u].push_back(i);
		g[E[i].v].push_back(i);
		isb[i] = 0;
	}
	dfs_bridge(0, -1);
	int cnt = 0;
	fill(used, used + n, 0);
	for (int i = 0; i < n; i++) {
		if (!used[i]) {
			dfs_ignore(i, cnt);
			cnt++;
		}
	}
	for (int i = 0; i < last; i++) {
		int cf = comp[E[i].v];
		int cs = comp[E[i].u];
		if (cf == cs) {
			me[cf] = min(me[cf], E[i].c);
		} else {
			ng[cf].push_back({cs, E[i].c});
			ng[cs].push_back({cf, E[i].c});
		}
	}
	dfs_ans(0, -1, INF);
	for (int i = 0; i < n; i++) {
		ans[i] = min(ans[i], ac[comp[i]] + E[last - 1].c);
	}
}

signed main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);


	int m;
	cin >> n >> m;
	for (int i = 0; i < m; i++) {
		int u, v, c;
		cin >> u >> v >> c;
		u--;
		v--;
		E.push_back(Edge(u, v, c)); 
	}
	sort(E.begin(), E.end());
	fill(ans, ans + n, 2LL * INF);
	for (int i = 0; i < m; i++) {
		solve(i + 1);
	}
	for (int i = 1; i < n; i++) {
		cout << ans[i] << '\n';
	}
}