#pragma GCC optimize("O3")
#pragma GCC target("avx2")
#include <iostream>
#include <cstdio>
#include <vector>
#include <map>
#include <set>
#include <algorithm>
#include <cassert>
#include <cstring>
#include <utility>
#include <queue>
using namespace std;
using vi  = vector<int>;
using pii  = pair<int, int>;


const int PINF{INT_MAX}, NINF{INT_MIN};

struct SegTree
{
    int n = 1, n2;
    vi lm, rm;

    void up(int v)
    {
        if (v < n)
        {
            lm[v] = min(lm[2*v], lm[2*v+1]);
            rm[v] = max(rm[2*v], rm[2*v+1]);
        }
    }

    void reset()
    {
        for (int i = 0; i < n2; i++)
        {
            lm[n+i] = i;
            rm[n+i] = i;
        }
        for (int i = n-1; i >= 1; i--)
            up(i);
    }

    SegTree(int _n2): n2(_n2)
    {
        while (n < n2)
            n *= 2;

        lm.assign(2*n, 0);
        rm.assign(2*n, 0);
        reset();
    }

    void del(int x)
    {
        x += n;
        lm[x] = PINF;
        rm[x] = NINF;
        for (; x >= 1; x >>= 1)
            up(x);
    }

    int get_clr(int x)
    {
        int res = PINF;
        int L = x+1, R = n2;
        for (L += n, R += n; L < R; L >>= 1, R >>= 1)
        {
            if (L & 1)
                res = min(res, lm[L++]);
            if (R & 1)
                res = min(res, lm[--R]);
        }
        return res;
    }

    int get_cll(int x)
    {
        int res = NINF;
        int L = 0, R = x;
        for (L += n, R += n; L < R; L >>= 1, R >>= 1)
        {
            if (L & 1)
                res = max(res, rm[L++]);
            if (R & 1)
                res = max(res, rm[--R]);
        }
        return res;
    }
};


constexpr int N{500000};
int x[N], h[N];
int n;
bool used[N];
SegTree *ST;


inline bool isok(int i)
{
    //cout << "isok " << i+1 << '\n';
    int cr = ST->get_clr(i);
    int cl = ST->get_cll(i);
    //cout << cl+1 << ' ' << cr+1 << '\n';
    return cl >= 0 && x[i]-x[cl] >= h[i] ||
           cl == NINF && x[i]-x[0] >= h[i] ||
           cr < n && x[cr]-x[i] >= h[i] ||
           cr == PINF && x[n-1]-x[i] >= h[i];
}


signed main()
{
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int q;
    cin >> n >> q;

    ST = new SegTree(n);

    for (int i = 0; i < n; i++)
        cin >> x[i] >> h[i];

    while (q--)
    {
        ST->reset();
        memset(used, 0, n);

        int l, r;
        cin >> l >> r;
        l--; r--;

        queue<int> sus;
        for (int i = l; i <= r; i++)
            if (isok(i))
            {
                used[i] = true;
                sus.push(i);
            }

        int res = 0;
        while (!sus.empty())
        {
            int v = sus.front();
            sus.pop();
            // cout << "v " << v+1 << '\n';

            ST->del(v);
            res++;

            for (int u = v-1; u <= v+1; u += 2)
            {
                if (l <= u && u <= r && !used[u] && isok(u))
                {
                    used[u] = true;
                    sus.push(u);
                }
            }
        }

        cout << res << '\n';
    }

    return 0;
}

/*
3 3
1 3
3 1
4 2
1 1
2 3
1 3
*/
