#include <iostream>
#include <algorithm>
#include <vector>
#include <string>
#include <cstring>
#include <set>
#include <map>
#include <queue>
#include <random>
#include <iomanip>

using namespace std;

template<typename T> void uin(T &a, T b) {
	if (b < a) a = b;
}
template<typename T> void uax(T &a, T b) {
	if (b > a) a = b;
}

#define int long long
#define left left228
#define right right228
#define list list228
#define all(v) v.begin(), v.end()

const int N = 300 * 1000 + 7;
const int INF = 1e18 + 228;

int n, m;
vector< pair<int, int> > g[N];


struct edge
{
	int u, v, t;
	edge() {}
	edge(int _u, int _v, int _t) {
		u = _u;
		v = _v;
		t = _t;
	}
};

vector< edge > edges;

vector<int> gr[N];
int ans[N];
int comp[N];
int fup[N], tin[N], timer = 0;
bool used[N];
map< pair<int, int>, bool > is_bridge;
map< pair<int, int>, int> cnt, cost;

int min_t[N];

void dfs(int v, int par = -1) {
	fup[v] = tin[v] = timer++;
	used[v] = true;

	for (auto go : g[v]) {
		int to = go.first, t = go.second;

		if (to == par) {
			continue;
		}

		if (used[to]) {
			uin(fup[v], tin[to]);
		} else {
			dfs(to, v);
			uin(fup[v], fup[to]);

			if (cnt[{v, to}] == 1 && fup[to] >= tin[to]) {
				is_bridge[{v, to}] = is_bridge[{to, v}] = true;
			}
		}
	}
}

void dfs_color(int v, int cur_comp) {
	comp[v] = cur_comp;

	for (auto go : g[v]) {
		int to = go.first;
		if (!comp[to] && !is_bridge[{v, to}]) {
			dfs_color(to, cur_comp);
		}
	}
}

void dfs_comp(int v, int par = -1) {
	if (par != -1) {
		min_t[v] = min(min_t[v], min_t[par]);
	}
	for (int to : gr[v]) {
		if (to != par) {
			min_t[to] = min(min_t[to], cost[{v, to}]);
			dfs_comp(to, v);
		}
	}
}

void solve_tmax(int tmax, vector< edge > ed) {
	for (int v = 1; v <= n; ++v) {
		g[v].clear();
		gr[v].clear();
		used[v] = 0;
		comp[v] = 0;
	}
	is_bridge.clear();
	cnt.clear();
	cost.clear();

	for (auto e : ed) {
		int u = e.u, v = e.v, t = e.t;
		++cnt[{u, v}];
		++cnt[{v, u}];
		g[u].emplace_back(v, t);
		g[v].emplace_back(u, t);
	}
	timer = 0;
	dfs(1);

	int n_comp = 0;

	for (int v = 1; v <= n; ++v) {
		if (!comp[v]) {
			dfs_color(v, ++n_comp);
		}
	}

	

	map< pair<int, int>, bool > added;

	for (int i = 1; i <= n; ++i) {
		min_t[i] = INF;
	}

	for (auto e : ed) {
		int u = e.u;
		int v = e.v;
		int t = e.t;

		u = comp[u];
		v = comp[v];

		if (!cost.count({u, v}) || t < cost[{u, v}]) {
			cost[{u, v}] = t;
		}
		if (!cost.count({v, u}) || t < cost[{v, u}]) {
			cost[{v, u}] = t;
		}

		if (u != v && !added.count({u, v})) {

			added[{u, v}] = added[{v, u}] = true;
			gr[u].push_back(v);
			gr[v].push_back(u);
		}

		if (u == v) {
			uin(min_t[u], t);
		}
	}


	dfs_comp(comp[1]);

	for (int v = 2; v <= n; ++v) {
		if (used[v]) {
			// cout << "uin(ans[" << v << "], tmax=" << tmax << " min_t=" << min_t[comp[v]] << endl;
			uin(ans[v], tmax + min_t[comp[v]]);
		}
	}
}


void solve() {
	for (int i = 1; i <= n; ++i) {
		ans[i] = INF;
	}
	sort(all(edges), [&] (edge a, edge b) {
		return a.t < b.t;
	});
	vector< edge > sub_edges;
	int i = 0;
	while (i < m) {
		int j = i;
		sub_edges.push_back(edges[i]);
		while (j + 1 < m && edges[j + 1].t == edges[i].t) {
			++j;
			sub_edges.push_back(edges[j]);
		}

		int tmax = edges[i].t;

		solve_tmax(tmax, sub_edges);

		i = j + 1;
	}

	for (int i = 2; i <= n; ++i) {
		cout << ans[i] << '\n';
	}
}

signed main() {
	ios_base::sync_with_stdio(false);
	cin.tie(0);
	cin >> n >> m;

	for (int i = 0; i < m; ++i) {
		int u, v, t;
		cin >> u >> v >> t;
		g[u].emplace_back(v, t);
		g[v].emplace_back(u, t);
		edges.emplace_back(u, v, t);
	}

	solve();
	return 0;
}


/*

4 4
1 2 2
3 2 0
2 4 3
4 3 1

*/