#include <iostream>
#include <vector>
#include <sstream>
#include <set>
#include <map>
#include <assert.h>
#include <cmath>
#include <algorithm>
#include <math.h>

using namespace std;
typedef long long LL;
typedef unsigned long long ULL;

typedef pair<int, int> Edge;

int ABS(int a) {
if((a) < 0) return -(a);
return (a);
}

struct Graph {
	int size;
	vector<set<int>> neighbours;
	set<Edge> edges;

	vector<pair<Edge, Edge>> answer;

	vector<bool> used;

	Graph() {}

	Graph(int s) {
		size = s;
		neighbours.resize(size);
		used.resize(size, false);
	}

	void addEdge(int from, int to) {
		neighbours[from].insert(to);
		neighbours[to].insert(from);
		
		edges.insert({ from, to });
	}

	bool checkMatch(int vertex, int parent, Edge& needMatch) {
		used[vertex] = true;
		set<Edge> toMatchFrom;
		set<Edge> toMatchTo;

		for (auto v : neighbours[vertex])
		{
			if (v == parent) continue;

			Edge t = {-1, -1};
			bool ok = checkMatch(v, vertex, t);
			if (!ok) return false;

			if (t.first != -1) {
				if (t.first == vertex) {
					toMatchFrom.insert(t);
				}
				else {
					toMatchTo.insert(t);
				}
			}
		}

		if (ABS(toMatchFrom.size() - toMatchTo.size()) > 1) {
			return false;
		}
		auto fPtr = toMatchFrom.begin();
		auto sPtr = toMatchTo.begin();

		for (; fPtr != toMatchFrom.end() && sPtr != toMatchTo.end(); fPtr++)
		{
			answer.push_back({ *sPtr, *fPtr });
			sPtr++;
		}

		if (fPtr != toMatchFrom.end()) {
			if (edges.find({ parent, vertex }) != edges.end()) {
				answer.push_back({ {parent, vertex}, *fPtr });
				if (edges.find({ vertex, parent }) != edges.end()) {
					needMatch = { vertex, parent };
				}
				return true;
			}
			else {
				return false;
			}
		}

		if (sPtr != toMatchTo.end()) {
			if (edges.find({ vertex, parent }) != edges.end()) {
				answer.push_back({ {vertex, parent}, *fPtr });
				if (edges.find({ parent, vertex }) != edges.end()) {
					needMatch = { parent, vertex };
				}
				return true;
			}
			else {
				return false;
			}
		}

		if (edges.find({ vertex, parent }) != edges.end()) {
			if (edges.find({ parent, vertex }) != edges.end()) {
				answer.push_back(
					{ {vertex, parent},
					{parent, vertex}
					});
			}
			else {
				needMatch = { vertex, parent };
			}
		}
		else if (edges.find({ parent, vertex }) != edges.end()) {
			needMatch = { parent, vertex };
		}

		return true;
	}

	bool calcAll() {
		for (int v = 0; v < size; v++)
		{
			if (used[v]) continue;

			Edge e = {-1, -1};
			bool ok = checkMatch(v, -1, e);

			if (!ok || e.first != -1) {
				return false;
			}
		}

		return true;
	}
};

int main() {
	ios::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);

	int n, m;
	cin >> n >> m;

	Graph G(n);

	for (int i = 0; i < m; i++)
	{
		int u, v;
		cin >> u >> v;
		u--;
		v--;

		G.addEdge(u, v);
	}

	bool ok = G.calcAll();

	if (!ok) {
		cout << "No" << endl;
	}
	else {
		cout << "Yes" << endl;

		for (auto p : G.answer)
		{
			cout << p.first.first + 1 << " " << p.first.second + 1 << " " << p.second.first + 1 << " " << p.second.second + 1 << "\n";
		}
		cout << endl;
	}
}