#include <bits/stdc++.h>

using namespace std;

const int MAXN = 3e5 + 10, INF = 1e9;

struct Edge {
    int u, v, t;
    Edge(int v, int u, int t) : v(v), t(t), u(u) {}
    int to(int x) {
        return (x == u ? v : u);
    }
};

vector<Edge> edges;
vector<int> g[MAXN];

bitset<MAXN> isbridge;

int h[MAXN], fup[MAXN];
bitset<MAXN> used;

void dfs(int v, int idPred) {
    used[v] = true;
    for (auto id : g[v]) {
        if (id == idPred) {
            continue;
        }
        int u = edges[id].to(v);
        if (used[u]) {
            fup[v] = min(fup[v], h[u]);
        } else {
            h[u] = fup[u] = h[v] + 1;
            dfs(u, id);
            fup[v] = min(fup[v], fup[u]);
            if (h[v] < fup[u]) {
                isbridge[id] = true;
            }
        }
    }
}

int com[MAXN], color = 1;

void dfsColor(int v) {
    for (auto id : g[v]) {
        int u = edges[id].to(v);
        if (com[u] || isbridge[id]) {
            continue;
        }
        com[u] = com[v];
        dfsColor(u);
    }
}

int maxInCom[MAXN], minInCom[MAXN];

void dfsMinMax(int v) {
    used[v] = true;
    for (auto id : g[v]) {
        int u = edges[id].to(v);
        if (com[u] != com[v]) {
            continue;
        }
        maxInCom[com[v]] = max(maxInCom[com[v]], edges[id].t);
        minInCom[com[v]] = min(minInCom[com[v]], edges[id].t);
        if (!used[u]) {
            dfsMinMax(u);
        }
    }
}

vector<Edge> treedges;
vector<int> kekg[MAXN];

void buildTree() {
    for (int id = 0; id < edges.size(); id++) {
        int u = edges[id].u, v = edges[id].v;
        if (com[u] == com[v]) {
            continue;
        }
        u = com[u], v = com[v];
        kekg[u].push_back(treedges.size());
        kekg[v].push_back(treedges.size());
        treedges.push_back(Edge(v, u, edges[id].t));
    }
}

void dfsTree(int v, int p) {
    for (auto id : kekg[v]) {
        int u = treedges[id].to(v);
        if (u == p) {
            continue;
        }
        minInCom[u] = min({minInCom[u], minInCom[v], treedges[id].t});
        maxInCom[u] = max({maxInCom[u], maxInCom[v], treedges[id].t});
        dfsTree(u, v);
    }
}

signed main() {
    //freopen("input.txt", "r", stdin);
    fill(minInCom, minInCom + MAXN, INF);
    int n, m;
    cin >> n >> m;
    for (int i = 0; i < m; i++) {
        int u, v, t;
        cin >> u >> v >> t;
        u--, v--;
        g[u].push_back(edges.size());
        g[v].push_back(edges.size());
        edges.push_back(Edge(u, v, t));
    }
    dfs(0, -1);
    used.reset();
    for (int v = 0; v < n; v++) {
        if (!com[v]) {
            com[v] = color++;
            dfsColor(v);
        }
    }
    for (int v = 0; v < n; v++) {
        if (!used[v]) {
            dfsMinMax(v);
        }
    }
    used.reset();
    buildTree();
    dfsTree(1, -1);
    for (int k = 1; k < n; k++) {
        cout << minInCom[com[k]] + maxInCom[com[k]] << " ";
    }
}
