#include <iostream>
#include <vector>
#include <random>
#include <algorithm>

using namespace std;

mt19937 rnd(777);

struct node {
	node *L = 0, *R = 0;
	int x, y = rnd();
	node() {}
	node(int a) {x = a;} 
};

node* merge(node* a, node* b) {
	if (a == 0)
		return b;
	if (b == 0)
		return a;

	if (a->y > b->y) {
		a->R = merge(a->R, b);
		return a;
	} else {
		b->L = merge(a, b->L);
		return b;
	}
}

pair<node*, node*> split(node* a, int k) {
	if (a == 0)
		return {0, 0};
	if (a->x <= k) {
		auto z = split(a->R, k);
		a->R = z.first;
		return {a, z.second};
	} else {
		auto z = split(a->L, k);
		a->L = z.second;
		return {z.first, a};
	}
}

node* insert(node *a, node *b) {
	if (a == 0)
		return b;
	if (a->y > b->y) {
		return insert((a->x < b->x) ? a->R : a->L, b);
	} else {
		auto z = split(a, b->x);
		b->L = z.first, b->R = z.second;
		return b;
	}
}

struct SegTree {
	vector<int> t, mod;
	int n;

	void build(int v, int l, int r, vector<int> &a) {
		if (r - l == 1) {
			t[v] = a[l];
			return;
		}

		int m = (l + r) / 2;
		build(v * 2 + 1, l, m, a);
		build(v * 2, m, r, a);
		t[v] = min(t[v * 2 + 1], t[v * 2]);
	}

	SegTree(vector<int> a) {
		n = a.size();
		int sz = 1;
		while (sz < 2 * n)
			sz *= 2;
		t.resize(sz);
		mod.resize(sz);
		build(1, 0, n, a);
	}

	int get(int v, int l, int r, int L, int R) {
		if (R <= l || r <= L)
			return 1e9 + 228;
		if (L <= l && r <= R)
			return t[v];

		int m = (l + r) / 2;
		return min(get(v * 2 + 1, l, m, L, R), get(v * 2, m, r, L, R)) + mod[v];
	}

	void update(int v, int l, int r, int L, int R, int val) {
		if (R <= l || r <= L)
			return;
		if (L <= l && r <= R) {
			t[v] += val, mod[v] += val;
			return;
		}

		int m = (l + r) / 2;
		update(v * 2 + 1, l, m, L, R, val);
		update(v * 2, m, r, L, R, val);
		t[v] = min(t[v * 2 + 1], t[v * 2]) + mod[v];
	}

	int get(int l, int r) {
		return get(1, 0, n, l, r);
	}

	void update(int l, int r, int val) {
		update(1, 0, n, l, r, val);
	}
};

struct dsu {
	vector<int> p, sz;
	dsu(int n) {
		p.resize(n);
		sz.resize(n, 1);
		iota(p.begin(), p.end(), 0);
	}

	int get(int a) {
		if (a == p[a])
			return a;
		return p[a] = get(p[a]);
	}

	void merge(int a, int b) {
		a = get(a), b = get(b);
		if (a == b)
			return;
		if (sz[a] < sz[b])
			p[a] = b, sz[b] += sz[a];
		else
			p[b] = a, sz[a] += sz[b];
	}
};

int main() {
	ios_base::sync_with_stdio(0);
	cout.tie(0);
	cin.tie(0);

	int type;
	cin >> type;
	int n;
	cin >> n;
	if (type == 1) {
		int l = 0, r = n;
		while (r - l > 1) {
			int m = (l + r) / 2;
			cout << m << endl;
			int res;
			cin >> res;
			if (res == 0)
				return 0;
			else if (res == -1)
				r = m;
			else
				l = m;
		}
	} else {
		int q;
		cin >> q;
		int l = 0, r = n;
		for (int i = 0; i < q; ++i) {
			int m = (l + r) / 2;
			int res;
			cin >> res;
			if (res == 0) {
				cout << m << '\n';
				return 0;
			}
			else if (res == -1)
				r = m;
			else
				l = m;
		}
	}
}